@@ -46,7 +46,7 @@ class FrameworkType(Enum):
     DRUSH = "drush"
     
     # Unknown/No framework detected
-    UNKNOWN = "na"
+    UNKNOWN = ""
     
     @property
     def display_name(self) -> str:
